@@ -494,7 +494,7 @@ do_save_file (GSRWindow *window,
 	if (!g_spawn_command_line_sync (command,  NULL, NULL, &status, &error)) {
 		gchar *error_message;
 
-		error_message = g_strdup_printf (_("Could not save the file \" %s\""), error->message);
+		error_message = g_strdup_printf (_("Could not save the file \"%s\""), error->message);
 		show_error_dialog (GTK_WINDOW (window), error_message);
 		g_free (error_message);
 	}
@@ -502,7 +502,7 @@ do_save_file (GSRWindow *window,
 	if (status) {
 		gchar *error_message;
 
-		error_message = g_strdup_printf (_("Could not save the file \" %s\""), tmp);
+		error_message = g_strdup_printf (_("Could not save the file \"%s\""), tmp);
 		show_error_dialog (GTK_WINDOW (window), error_message);
 		g_free (error_message);
 	}
@@ -706,7 +706,8 @@ fill_in_information (GSRWindow *window,
 		char *human;
 		human = gnome_vfs_format_file_size_for_display (buf.st_size);
 
-		text = g_strdup_printf ("%s (%llu bytes)", human, buf.st_size);
+		text = g_strdup_printf (ngettext ("%s (%llu byte)", "%s (%llu bytes)", 
+						   buf.st_size), human, buf.st_size);
 		g_free (human);
 	} else {
 		text = g_strdup (_("Unknown size"));
@@ -853,7 +854,7 @@ file_properties (BonoboUIComponent *uic,
 	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
 	gtk_box_pack_start (GTK_BOX (hbox), table, TRUE, TRUE, 0);
 
-	label = make_info_label (_("Song length:"));
+	label = make_info_label (_("File duration:"));
 	pack_table_widget (table, label, 0, 0);
 
 	fp->length = make_info_label ("");
